function [] = plotSoundsourceToaFromGps(pSoundsources)
%PLOTSOUNDSOURCETOAFROMGPS Plots the given sound sources to the edit time of arrival plot.
%   Is called by artoa.controller.edit.timeOfArrival.plot()
%   CANNOT BE USED ISOLATED.
%
%   Parameters:
%       pSoundsources (struct)  The soundsources that are to be used.

global artoaDataInput artoaWorkspace artoaGui;

%% Initialize required variables
unappliedSoundsourcesColor = [0 0 0];

if isfield(artoaGui.editTimeOfArrival, 'axesToaFromGps') ...
        && isvalid(artoaGui.editTimeOfArrival.axesToaFromGps)
    % update color
    fnames = fieldnames(pSoundsources);
    for o = 1:length(fnames)
        if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
        [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
            artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
            for t = 1:length(artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o}))
                current = artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o})(t);
                current.Color = artoaWorkspace.soundsourceColors(colorIndex, :);
            end
            clear current;
            % update scatter
            artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}).MarkerEdgeColor = ...
                artoaWorkspace.soundsourceColors(colorIndex, :);
        else
            % update text
            for t = 1:length(artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o}))
                current = artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o})(t);
                current.Color = unappliedSoundsourcesColor;
            end
            clear current;
            % update scatter
            artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}).MarkerEdgeColor = ... 
                unappliedSoundsourcesColor;
        end    
    end
    return
end

artoaGui.editTimeOfArrival.axesToaFromGps = axes(artoaGui.figures.editTimeOfArrival);

artoaGui.editTimeOfArrival.scatterToaFromGps = struct();
artoaGui.editTimeOfArrival.textToaFromGps = struct();

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'on');

%% Collect required data
yMax = max(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);
yMin = min(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);

%% Create plot
fnames = fieldnames(pSoundsources);

for o = 1:length(fnames)
    % estimate the color to be used
    if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
        [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
            artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
        soundsourceColor = artoaWorkspace.soundsourceColors(colorIndex, :);
    else
        soundsourceColor = unappliedSoundsourcesColor;
    end
    % skip sound source if it went out of the water before the float range, or
    % went in the water after the float range
    soundSourceBegin = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).begemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(1));
    soundSourceEnd = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).endemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(1));

    [gpsDates, predictedToas] = artoa.data.predictToaFromGps( ...
        artoaDataInput.rfb, pSoundsources.(fnames{o}), ...
        struct( ...
            'temperature', artoaWorkspace.temperature(artoaWorkspace.statusTemperature == 1), ...
            'pressure', artoaWorkspace.pressure(artoaWorkspace.statusPressure == 1), ...
            'method', 'del grosso', ...
            'soundSource', NaN ...
        ), ...
        artoa.data.getMember(artoaDataInput, {'ini', 'leapseconds'}) ...
    );

    % remove gps dates that are past end mission of sound source
    selection = (gpsDates > soundSourceEnd);
    gpsDates(selection) = NaN;
    predictedToas(selection) = NaN;
    % remove gps dates before deployment of soundsource
    selection = (gpsDates < soundSourceBegin);
    gpsDates(selection) = NaN;
    predictedToas(selection) = NaN;
    clear selection;
    
    artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}) = scatter( ...
        artoaGui.editTimeOfArrival.axesToaFromGps, ...
        gpsDates, predictedToas, 50, ...
        'MarkerEdgeColor', soundsourceColor ...
    );
    
    % use only every third gps date
    gpsDates = gpsDates(1:3:end);
    predictedToas = predictedToas(1:3:end);
    
    artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o}) = text( ...
        artoaGui.editTimeOfArrival.axesToaFromGps, ...
        gpsDates, predictedToas, ['  ' fnames{o}], ...
        'HorizontalAlignment', 'left', ...
        'VerticalAlignment', 'top', ...
        'FontName', 'Helvetica', ...¬                                     
        'FontSize', 10, ...¬                                              
        'FontWeight', 'demi', ...¬                                        
        'Color', soundsourceColor ...%[1 1 1] ...
    );
end

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'off');


end

